@@ -1,5 +1,5 @@
 /* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,11 +22,12 @@
 #include <cmath>
 #include <stdexcept>
 #include <string>
-#include <boost/numeric/ublas/lu.hpp>
+#include <votca/tools/floatingpointcomparison.h>
+#include <votca/tools/eigen.h>
 #include "tokenizer.h"
 
 namespace votca { namespace tools {
-using namespace std;
+    using namespace std;
 /**
     \brief Vector class for a 3 component vector
 
@@ -41,12 +42,19 @@ class vec {
 public:
     
     vec();
+    vec(const double a);
     vec(const vec &v);
     vec(const double r[3]);
-    vec(const double &x, const double &y, const double &z);
-    vec(const boost::numeric::ublas::vector<double> &v);
-    vec(const string &str);
+    vec(const double x, const double y, const double z);
+    vec(const std::string &str);
+    vec(const Eigen::Vector3d &vec);
     
+    Eigen::Vector3d toEigen()const;
+    
+    
+    double operator[](std::size_t i) const;
+
+    double  &operator[](std::size_t i);
     
     vec &operator=(const vec &v);
     vec &operator+=(const vec &v);
@@ -99,6 +107,23 @@ public:
      */
     const double &getZ() const { return _z; }
     
+     /**
+       * \brief Compare floating point values of two vectors
+       *
+       * The floating point values are compared to within a tolerance which
+       * is specified as the third parameter.
+       *
+       * @param[in] v - vector to be compared
+       * @param[in] tol - tolerance 
+       * @return bool - return true if within tolerance and false if not
+       */
+      bool isClose(const vec& v, const double tol) const {
+        for (size_t i = 0; i < 3; ++i){
+          if (!isApproximatelyEqual(xyz[i], v.xyz[i],tol)) return false;
+        }
+        return true;
+}
+
     /**
      * \brief normalize the vector
      * @return normalized vector
@@ -107,37 +132,39 @@ public:
      */
     vec &normalize();
     
-    boost::numeric::ublas::vector<double> converttoub();
     
     template<class Archive>
     void serialize(Archive &arch, const unsigned int version) { arch & _x; arch & _y; arch & _z; }
     
     private:
-        double _x, _y, _z;
+        
+        union{
+            struct{
+                double _x;
+                double _y;
+                double _z;
+            };
+            double xyz[3];
+        };
 };
 
 inline vec::vec() {}
 
+inline vec::vec(const double a)
+    : _x(a), _y(a), _z(a) {}
+
 inline vec::vec(const vec &v)
     : _x(v._x), _y(v._y), _z(v._z) {}
         
 inline vec::vec(const double r[3])
     : _x(r[0]), _y(r[1]), _z(r[2]) {}
 
-inline vec::vec(const boost::numeric::ublas::vector<double> &v)
-    {try
-    {_x=v(0);
-     _y=v(1);
-     _z=v(2);
-    }
-    catch(std::exception &err){throw std::length_error("Conversion from ub::vector to votca-vec failed");} 
-}
 
-inline vec::vec(const string &str)
+inline vec::vec(const std::string &str)
 {
     // usage: vec(" 1  2.5  17 "); separator = spaces
     Tokenizer tok(str, " ");
-    vector< string > values;
+    std::vector< std::string > values;
     tok.ToVector(values);
     if (values.size()!=3)
     {
@@ -154,8 +181,32 @@ inline vec::vec(const string &str)
     }
 }
 
-inline vec::vec(const double &x, const double &y, const double &z)
+inline vec::vec(const Eigen::Vector3d &vec){
+    for (int i=0;i<3;i++){
+        xyz[i]=vec[i];
+    }
+}
+
+inline Eigen::Vector3d vec::toEigen() const{
+    Eigen::Vector3d result;
+    for (int i=0;i<3;i++){
+        result[i]=xyz[i];
+    }
+    return result;
+}
+
+inline vec::vec(const double x, const double y, const double z)
         : _x(x), _y(y), _z(z) {}
+
+inline double vec::operator[](std::size_t i) const {
+    assert(i<3 && "vec[] integer larger than 2");
+    return xyz[i];
+ }
+
+inline double  &vec::operator[](std::size_t i) {
+    assert(i<3 && "vec[] integer larger than 2");
+    return xyz[i];
+ }
     
 inline bool operator==(const vec &v1, const vec &v2)
 {
@@ -240,12 +291,12 @@ inline std::istream &operator>>(std::istream &in, vec& v)
         throw std::runtime_error("error, invalid character in vector string");
     }
     
-    string str;
+    std::string str;
     while (in.good()) {
         in.get(c);
         if(c==']') { // found end of vector
             Tokenizer tok(str, ",");
-            vector<double> d;
+            std::vector<double> d;
             tok.ConvertToVector(d);
             if(d.size() != 3)
                 throw std::runtime_error("error, invalid number of entries in vector");
@@ -285,6 +336,16 @@ return vec(
         v1.getZ()*v2.getZ() );
 }
 
+
+/// elementwise division
+inline vec elementwisedivison(const vec &v1, const vec &v2)
+{
+return vec(
+        v1.getX()/v2.getX() ,
+        v1.getY()/v2.getY() ,
+        v1.getZ()/v2.getZ() );
+}
+
 inline double abs(const vec &v)
 {
     return sqrt(v*v);
@@ -304,16 +365,6 @@ inline vec &vec::normalize()
 }
 
 
-
-inline boost::numeric::ublas::vector<double> vec::converttoub() {
-    boost::numeric::ublas::vector<double> temp=boost::numeric::ublas::zero_vector<double>(3);
-    temp(0)=_x;
-    temp(1)=_y;
-    temp(2)=_z;
-    return temp;
-
-
-}
 }}
 #endif	/* _vec_H */
 
