@@ -1,5 +1,5 @@
 /* 
- * Copyright 2009-2011 The VOTCA Development Team (http://www.votca.org)
+ * Copyright 2009-2018 The VOTCA Development Team (http://www.votca.org)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,6 +22,12 @@ namespace votca { namespace tools {
         bool globals::verbose = false;
         std::string globals::url = "http://www.votca.org";
         std::string globals::email = "devs@votca.org";
+        
+#if defined(MKL)
+        bool globals::VOTCA_MKL=true;
+#else
+        bool globals::VOTCA_MKL=false;
+#endif
 
         std::string globals::man::option(".TP\n\\fB%1%\\fR\n%2%\n");
 
